

package com.jgoodies.animation.examples.basic;

import com.jgoodies.animation.*;
import com.jgoodies.animation.animations.BasicTextAnimation;
import com.jgoodies.animation.components.BasicTextLabel;

import javax.swing.*;
import java.awt.*;
import java.util.LinkedList;
import java.util.List;

public final class MyBasic {
    
    private static final int DEFAULT_FRAME_RATE = 30;
	
	private JLabel		 	reportLabel;
	private BasicTextLabel label1;
	private BasicTextLabel label2;
	private BasicTextLabel label3;
	private BasicTextLabel label4;
	private BasicTextLabel label5;
	private BasicTextLabel label6;
	private BasicTextLabel label7;

	
	public static void main(String[] args) {
		int fps = DEFAULT_FRAME_RATE;
		new MyBasic (fps);
	}
	
	
	/**
	 * Constructs an animation demo using the specified frame rate.
     * 
     * @param fps   the frames per second
	 */
	private MyBasic (int fps) {
		createComponents();
		buildFrame(buildContent());
		
		Animator animator = new Animator(createComposedAnimation(), fps);
		animator.start();
	}


	// Building ***************************************************************
	
	/**
	 * Creates and configures the components used by the animations.
	 */
	private void createComponents() {
		Font font = new Font("dialog", Font.BOLD, 16);

		reportLabel = new JLabel();

		label1 = new BasicTextLabel(" "); label1.setFont(font);
		label2 = new BasicTextLabel(" "); label2.setFont(font);
		label3 = new BasicTextLabel(" "); label3.setFont(font);
		label4 = new BasicTextLabel(" "); label4.setFont(font);
		label5 = new BasicTextLabel(" "); label5.setFont(font);
		label6 = new BasicTextLabel(" "); label6.setFont(font);
		label7 = new BasicTextLabel(" "); label7.setFont(font);
	}
	

	/**
	 * Builds and opens the demo frame.
	 * @param i_pane
	 */	
	private void buildFrame (Container i_pane) {
		JFrame frame = new JFrame();
		frame.setUndecorated (true);
		frame.setContentPane(i_pane);
		frame.setSize(400, 300);
		frame.setTitle("JGoodies Animation :: Intro Example");
		frame.setDefaultCloseOperation(3); // EXIT_ON_CLOSE
        locateOnScreenCenter(frame);
		frame.setVisible(true);
	}
	

	/**
	 * Builds and answers the frame's content pane.
     * 
     * @return the built content
	 */
	private Container buildContent() {
		JPanel panel = new JPanel(new GridLayout(4, 0));
		panel.add(reportLabel);
		panel.add(label1);
		panel.add(label2);
		panel.add(label3);
		panel.add(label4);
		panel.add(label5);
		panel.add(label6);
		panel.add(label7);
		panel.setBorder(BorderFactory.createEmptyBorder(12, 12, 12, 12));
		return panel;
	}


	// Animation Creation *****************************************************
		
	private Animation createComposedAnimation() {
		List animations = new LinkedList();
		
		animations.add(BasicTextAnimation.defaultFade(label1,
													  6000,
													  "1. Default Fade",
													  Color.blue));
		animations.add(BasicTextAnimation.defaultScale(label2,
													   5000,
													   "2.  Default Scale",
													   Color.darkGray));
		animations.add(BasicTextAnimation.defaultSpace(label3, 4000,
													   "3.  Default Space",
													   Color.red));
//		animations.add(BasicTextAnimation.defaultSpaceColorFunction(3000, Color.red));
		animations.add (BasicTextAnimation.defaultSpace(label5, 3000,
													   "5.  Default Space",
													   Color.red));
		animations.add(BasicTextAnimation.defaultSpace(label6, 2000,
													   "6.  Default Space",
													   Color.red));
		Animation composedAnimation = Animations.parallel(animations);
		return composedAnimation;
	}


    private void locateOnScreenCenter(Component component) {
        Dimension paneSize = component.getSize();
        Dimension screenSize = component.getToolkit().getScreenSize();
        component.setLocation(
            (screenSize.width  - paneSize.width)  / 2,
            (screenSize.height - paneSize.height) / 2);
    }
}