

package com.jgoodies.animation.examples.intro;

import com.jgoodies.animation.AnimationUtils;
import com.jgoodies.animation.Animator;

import javax.swing.*;
import java.awt.*;

/** 
 * The main class for the JGoodies Animation's Intro demo.
 * Builds a frame, forwards the content building to the
 * <code>My2IntroPage</code> and runs the application.
 * 
 * @author Karsten Lentzsch
 * @version $Revision: 1.4 $
 */
public final class Intro {
	
    /**
     * The frame rate used if no runtime argument has been specified.
     */
    private static final int DEFAULT_FRAME_RATE = 30;

    /**
     * Refers to the page that renders the intro.
     */
    private My2IntroPage __my2IntroPage;
    
    
    public static void main(String[] args) {
        // Try to get the framerate from the command-line.
        int fps = DEFAULT_FRAME_RATE;
        if (args.length > 0) {
            try {
                fps = Integer.parseInt(args[0]);
            } catch (NumberFormatException e) {
                System.out.println("Could not parse the custom frame rate: " + args[0]);
            }
        }
        System.out.println("The desired framerate is " + fps + '.');    
        new Intro(fps);
    }
    
    
    /**
     * Constructs an animation demo using the specified frame rate.
     * 
     * @param fps   the animation's frame rate
     */
    private Intro(int fps) {
        buildFrame();

        Runnable runnable = new Runnable() {
            public void run() {
                JOptionPane.showMessageDialog(null, "The End.");
            }
        };

	    AnimationUtils.invokeOnStop(__my2IntroPage.animation, runnable);
	    Animator animator = new Animator(__my2IntroPage.animation, fps);
        animator.start();
    }


    // Building ***************************************************************
    
    /**
     * Builds and opens the demo frame.
     */ 
    private void buildFrame() {
        JFrame frame = new JFrame();
        frame.setContentPane(buildContent());
        frame.setSize(350, 150);
        frame.setTitle("JGoodies Animation :: Intro");
        frame.setDefaultCloseOperation(3); // EXIT_ON_CLOSE
        locateOnScreenCenter(frame);
        frame.setVisible(true);
    }
    

    /**
     * Builds and answers the frame's content pane.
     * 
     * @return the frame's content pane
     */
    private Container buildContent() {
        __my2IntroPage = new My2IntroPage ();
        return __my2IntroPage.build();
    }


    // Helper Code ***********************************************************
    
    /**
     * Locates the given component on the screen's center.
     * 
     * @param component   the component to be centered
     */
    private void locateOnScreenCenter(Component component) {
        Dimension paneSize = component.getSize();
        Dimension screenSize = component.getToolkit().getScreenSize();
        component.setLocation(
            (screenSize.width  - paneSize.width)  / 2,
            (screenSize.height - paneSize.height) / 2);
    }


}